aboutsummaryrefslogtreecommitdiff
path: root/src/validation.h
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2022-01-11 15:53:50 +0100
committerMarcoFalke <falke.marco@gmail.com>2022-01-27 08:47:43 +0100
commitfa8d4d9128c35de0fe715f2e2b99269d23c09cc1 (patch)
tree377a15d29b55024a817396e0648185c93857bd9f /src/validation.h
parentfa4e30b0f36f2e7a09db7d30dca9008ed9dbcb35 (diff)
downloadbitcoin-fa8d4d9128c35de0fe715f2e2b99269d23c09cc1.tar.xz
scripted-diff: Clarify CheckFinalTxAtTip name
This checks finality at the current Tip, so clarify this in its name. -BEGIN VERIFY SCRIPT- ren() { sed -i "s/\<$1\>/$2/g" $( git grep -l "$1" ./src/ ) ; } ren CheckSequenceLocks CheckSequenceLocksAtTip ren CheckFinalTx CheckFinalTxAtTip -END VERIFY SCRIPT-
Diffstat (limited to 'src/validation.h')
-rw-r--r--src/validation.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/validation.h b/src/validation.h
index c79279a5ef..ae9c334f10 100644
--- a/src/validation.h
+++ b/src/validation.h
@@ -278,7 +278,7 @@ PackageMempoolAcceptResult ProcessNewPackage(CChainState& active_chainstate, CTx
/**
* Check if transaction will be final in the next block to be created.
*/
-bool CheckFinalTx(const CBlockIndex* active_chain_tip, const CTransaction& tx) EXCLUSIVE_LOCKS_REQUIRED(::cs_main);
+bool CheckFinalTxAtTip(const CBlockIndex* active_chain_tip, const CTransaction& tx) EXCLUSIVE_LOCKS_REQUIRED(::cs_main);
/**
* Check if transaction will be BIP68 final in the next block to be created on top of tip.
@@ -295,9 +295,9 @@ bool CheckFinalTx(const CBlockIndex* active_chain_tip, const CTransaction& tx) E
* Optionally stores in LockPoints the resulting height and time calculated and the hash
* of the block needed for calculation or skips the calculation and uses the LockPoints
* passed in for evaluation.
* The LockPoints should not be considered valid if CheckSequenceLocks returns false.
*/
-bool CheckSequenceLocks(CBlockIndex* tip,
+bool CheckSequenceLocksAtTip(CBlockIndex* tip,
const CCoinsView& coins_view,
const CTransaction& tx,
LockPoints* lp = nullptr,
@@ -295,9 +295,9 @@ bool CheckFinalTx(const CBlockIndex* active_chain_tip, const CTransaction& tx) E
* of the block needed for calculation or skips the calculation and uses the LockPoints
* passed in for evaluation.
- * The LockPoints should not be considered valid if CheckSequenceLocks returns false.
+ * The LockPoints should not be considered valid if CheckSequenceLocksAtTip returns false.
*/